@@ -116,14 +116,14 @@ timeROC<-function(T,delta,marker,other_markers=NULL,cause,weighting="marginal",t
   rownames(Stats)<-times_names
   # }}}
   # {{{  computation of weights (1/2)
-  # we need to order to use the ipcw() fonction
+  # we need to order to use the pec::ipcw() fonction
   order_T<-order(T)
   T <- T[order_T]
   delta <- delta[order_T]
   marker<- marker[order_T]
   # use ipcw function from pec package
   if(weighting=="marginal"){
-    weights <- ipcw(Surv(failure_time,status)~1,data=data.frame(failure_time=T,status=as.numeric(delta!=0)),method="marginal",times=times,subjectTimes=T,subjectTimesLag=1)
+    weights <- pec::ipcw(Surv(failure_time,status)~1,data=data.frame(failure_time=T,status=as.numeric(delta!=0)),method="marginal",times=times,subjectTimes=T,subjectTimesLag=1)
   }
   if(weighting=="cox"){
     if (missing(other_markers)){marker_censoring<-marker } 
@@ -132,7 +132,7 @@ timeROC<-function(T,delta,marker,other_markers=NULL,cause,weighting="marginal",t
     colnames(marker_censoring)<-paste("X", 1:ncol(marker_censoring), sep="")
     fmla <- as.formula(paste("Surv(T,status)~", paste(paste("X", 1:ncol(marker_censoring), sep=""), collapse= "+")))
     data_weight<-as.data.frame(cbind(data.frame(T=T,status=as.numeric(delta!=0)),marker_censoring))
-    weights <- ipcw(fmla,data=data_weight,method="cox",times=as.matrix(times),subjectTimes=data_weight[,"T"],subjectTimesLag=1)
+    weights <- pec::ipcw(fmla,data=data_weight,method="cox",times=as.matrix(times),subjectTimes=data_weight[,"T"],subjectTimesLag=1)
   }
   if(weighting=="aalen"){
     if (missing(other_markers)){marker_censoring<-marker }
@@ -141,7 +141,7 @@ timeROC<-function(T,delta,marker,other_markers=NULL,cause,weighting="marginal",t
     colnames(marker_censoring)<-paste("X", 1:ncol(marker_censoring), sep="")
     fmla <- as.formula(paste("Surv(T,status)~", paste(paste("X", 1:ncol(marker_censoring), sep=""), collapse= "+")))
     data_weight<-as.data.frame(cbind(data.frame(T=T,status=as.numeric(delta!=0)),marker_censoring))
-    weights <- ipcw(fmla,data=data_weight,method="aalen",times=as.matrix(times),subjectTimes=data_weight[,"T"],subjectTimesLag=1)
+    weights <- pec::ipcw(fmla,data=data_weight,method="aalen",times=as.matrix(times),subjectTimes=data_weight[,"T"],subjectTimesLag=1)
   }
   # we order by marker values (in order to compute Se and Sp)
   order_marker<-order(-marker)
